==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/java.hints/src/org/netbeans/modules/java/hints/bugs/CastVSInstanceOf.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.java.hints.bugs;

import com.sun.source.util.TreePath;
import javax.lang.model.type.TypeMirror;
import javax.lang.model.util.Types;
import org.netbeans.spi.java.hints.Hint;
import org.netbeans.spi.java.hints.TriggerPattern;
import org.netbeans.spi.java.hints.TriggerPatterns;
import org.netbeans.spi.java.hints.HintContext;
import org.netbeans.spi.java.hints.ErrorDescriptionFactory;
import org.netbeans.spi.editor.hints.ErrorDescription;
import org.netbeans.spi.java.hints.Hint.Options;
import org.openide.util.NbBundle;

/**
 *
 * @author lahvac
 */
@Hint(displayName = "#DN_org.netbeans.modules.java.hints.bugs.CastVSInstanceOf", description = "#DESC_org.netbeans.modules.java.hints.bugs.CastVSInstanceOf", category="bugs", suppressWarnings="CastConflictsWithInstanceof", options=Options.QUERY)
public class CastVSInstanceOf {

    @TriggerPatterns({
        @TriggerPattern(value="if ($var instanceof $instanceofClass) {" +
                              "$type $name = ($castClass) $var;" +
                              "$stmts$;" +
                              "}"),
        @TriggerPattern(value="if ($var instanceof $instanceofClass) {" +
                              "final $type $name = ($castClass) $var;" +
                              "$stmts$;" +
                              "}"),
        @TriggerPattern(value="if ($var instanceof $instanceofClass) {" +
                              "$name = ($castClass) $var;" +
                              "$stmts$;" +
                              "}")
    })
    public static ErrorDescription hint(HintContext ctx) {
        TypeMirror tm1 = ctx.getInfo().getTrees().getTypeMirror(ctx.getVariables().get("$instanceofClass"));
        TreePath castClass = ctx.getVariables().get("$castClass");
        TypeMirror tm2 = ctx.getInfo().getTrees().getTypeMirror(castClass);
        Types t = ctx.getInfo().getTypes();

        if (tm1 == null || tm2 == null) {
            return null;
        }

        tm1 = t.erasure(tm1);
        tm2 = t.erasure(tm2);

        if (t.isSubtype(tm1, tm2)) {
            return null;
        }

        if (t.isSubtype(tm2, tm1)) {
            return null;
        }

        return ErrorDescriptionFactory.forTree(ctx, castClass, NbBundle.getMessage(CastVSInstanceOf.class,"ERR_CastVSInstanceOf"));
    }

}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/java.hints/src/org/netbeans/modules/java/hints/bugs/CastVSInstanceOf.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.java.hints.bugs;

import com.sun.source.util.TreePath;
import javax.lang.model.type.TypeMirror;
import javax.lang.model.util.Types;
import org.netbeans.modules.java.hints.errors.Utilities;
import org.netbeans.spi.java.hints.Hint;
import org.netbeans.spi.java.hints.TriggerPattern;
import org.netbeans.spi.java.hints.TriggerPatterns;
import org.netbeans.spi.java.hints.HintContext;
import org.netbeans.spi.java.hints.ErrorDescriptionFactory;
import org.netbeans.spi.editor.hints.ErrorDescription;
import org.netbeans.spi.java.hints.Hint.Options;
import org.openide.util.NbBundle;

/**
 *
 * @author lahvac
 */
@Hint(displayName = "#DN_org.netbeans.modules.java.hints.bugs.CastVSInstanceOf", description = "#DESC_org.netbeans.modules.java.hints.bugs.CastVSInstanceOf", category="bugs", suppressWarnings="CastConflictsWithInstanceof", options=Options.QUERY)
public class CastVSInstanceOf {

    @TriggerPatterns({
        @TriggerPattern(value="if ($var instanceof $instanceofClass) {" +
                              "$type $name = ($castClass) $var;" +
                              "$stmts$;" +
                              "}"),
        @TriggerPattern(value="if ($var instanceof $instanceofClass) {" +
                              "final $type $name = ($castClass) $var;" +
                              "$stmts$;" +
                              "}"),
        @TriggerPattern(value="if ($var instanceof $instanceofClass) {" +
                              "$name = ($castClass) $var;" +
                              "$stmts$;" +
                              "}")
    })
    public static ErrorDescription hint(HintContext ctx) {
        TypeMirror tm1 = ctx.getInfo().getTrees().getTypeMirror(ctx.getVariables().get("$instanceofClass"));
        TreePath castClass = ctx.getVariables().get("$castClass");
        TypeMirror tm2 = ctx.getInfo().getTrees().getTypeMirror(castClass);
        Types t = ctx.getInfo().getTypes();

        if (!(Utilities.isValidType(tm1) && Utilities.isValidType(tm2))) {
            return null;
        }

        tm1 = t.erasure(tm1);
        tm2 = t.erasure(tm2);

        if (t.isSubtype(tm1, tm2)) {
            return null;
        }

        if (t.isSubtype(tm2, tm1)) {
            return null;
        }

        return ErrorDescriptionFactory.forTree(ctx, castClass, NbBundle.getMessage(CastVSInstanceOf.class,"ERR_CastVSInstanceOf"));
    }

}
